@@ -1,4 +1,5 @@
 package Provision::Unix::DNS;
+# ABSTRACT: generic class for common DNS tasks
 
 use strict;
 use warnings;
@@ -189,15 +190,17 @@ sub _get_server {
 }
 
 1;
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Provision::Unix::DNS - A generic class for common DNS tasks
+Provision::Unix::DNS - generic class for common DNS tasks
 
 =head1 VERSION
 
-Version 0.23
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -210,7 +213,6 @@ The Provision::Unix::DNS provides a consistent API for managing DNS zones and re
 
     $dns->zone_modify( zone=>'example.com', hostmaster=>'dnsadmin@admin-zone.com' );
 
-
 =head1 DESCRIPTION
 
 Rather than write code to generate BIND zone files, tinydns data files, or API calls to various servers, write your application to use Provision::Unix::DNS instead. The higher level DNS class contains methods for each type of DNS task as well as error handling, rollback support, and logging. Based on the settings in your provision.conf file, your request will be dispatched to your DNS Server of choice.  Subclasses are created for each type of DNS server.
@@ -225,24 +227,16 @@ Support is included for NicTool via its native API and tinydns. I will leave it
 
 =head2 get_zone
 
-=head1 AUTHOR
-
-Matt Simerson, C<< <matt at tnpi.net> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-unix-provision-dns at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Provision-Unix>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Provision::Unix::DNS
 
-
 You can also look for information at:
 
 =over 4
@@ -265,17 +259,21 @@ L<http://search.cpan.org/dist/Provision-Unix>
 
 =back
 
+=head1 AUTHOR
 
-=head1 ACKNOWLEDGEMENTS
+Matt Simerson <msimerson@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Matt Simerson
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2011 by The Network People, Inc..
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
+
