@@ -1,19 +1,26 @@
 package Provision::Unix::DNS::BIND;
+# ABSTRACT: Provision BIND DNS entries
 
-use warnings;
 use strict;
+use warnings;
 
 our $VERSION = '0.02';
 
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Provision::Unix::DNS::BIND - Provision BIND DNS entries
 
+=head1 VERSION
+
+version 1.01
+
 =head1 SYNOPSIS
 
 Provision DNS entries for a BIND DNS server. Not sure yet about backend support
@@ -25,23 +32,16 @@ file, but what about database backend? subclass them? (probably)
     my $foo = Provision::Unix::DNS::BIND->new();
     ...
 
-
-=head1 AUTHOR
-
-Matt Simerson, C<< <matt at tnpi.net> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-unix-provision-dns at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Provision-Unix>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Provision::Unix::DNS::BIND
 
-
 You can also look for information at:
 
 =over 4
@@ -64,14 +64,21 @@ L<http://search.cpan.org/dist/Provision-Unix>
 
 =back
 
+=head1 AUTHOR
 
-=head1 COPYRIGHT & LICENSE
+Matt Simerson <msimerson@cpan.org>
 
-Copyright 2008 Matt Simerson
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2011 by The Network People, Inc..
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
+
