@@ -1,7 +1,8 @@
 package Provision::Unix::User::Darwin;
+# ABSTRACT: provision user accounts on Darwin systems
 
-use warnings;
 use strict;
+use warnings;
 
 our $VERSION = '0.16';
 
@@ -114,7 +115,6 @@ sub _next_uid {
 }
 
 sub _create_dscl {
-
     my $self = shift;
 
     my $user  = $p_user->{username};
@@ -162,7 +162,6 @@ sub _create_dscl {
 }
 
 sub _create_niutil {
-
     my $self  = shift;
     my $user  = $p_user->{username};
     my $debug = $p_user->{debug};
@@ -210,7 +209,6 @@ sub _create_niutil {
 }
 
 sub destroy {
-
     my $self = shift;
 
     my %p = validate(
@@ -358,12 +356,17 @@ sub exists_group {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Provision::Unix::User::Darwin - Provision Accounts on Darwin systems
+Provision::Unix::User::Darwin - provision user accounts on Darwin systems
 
+=head1 VERSION
+
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -380,23 +383,16 @@ Handles provisioning operations (create, modify, destroy) for system users on UN
 
 Creates and returns a new Provision::Unix::User::Darwin object.
 
-
-=head1 AUTHOR
-
-Matt Simerson, C<< <matt at tnpi.net> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-unix-provision-user at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Provision-Unix>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Provision::Unix::User::Darwin
 
-
 You can also look for information at:
 
 =over 4
@@ -419,17 +415,21 @@ L<http://search.cpan.org/dist/Provision-Unix>
 
 =back
 
+=head1 AUTHOR
 
-=head1 ACKNOWLEDGEMENTS
+Matt Simerson <msimerson@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Matt Simerson
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2011 by The Network People, Inc..
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
+
