@@ -1,10 +1,11 @@
 package Provision::Unix::VirtualOS::FreeBSD::Ezjail;
+# ABSTRACT: provision freebsd jails using ezjail
+
+use strict;
+use warnings;
 
 our $VERSION = '0.11';
 
-use warnings;
-use strict;
-
 use English qw( -no_match_vars );
 use Params::Validate qw(:all);
 
@@ -94,10 +95,36 @@ sub _get_jails_root {
         ( undef, $r ) = split /=/, $r;
         return $r;
     }
-    return undef;
+    return;
 }
 
 1;
 
+
+
+=pod
+
+=head1 NAME
+
+Provision::Unix::VirtualOS::FreeBSD::Ezjail - provision freebsd jails using ezjail
+
+=head1 VERSION
+
+version 1.01
+
+=head1 AUTHOR
+
+Matt Simerson <msimerson@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by The Network People, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
 __END__
 
