@@ -1,10 +1,11 @@
 package Provision::Unix::VirtualOS::Linux::Xen;
+# ABSTRACT: provision a linux VPS using Xen
+
+use strict;
+use warnings;
 
 our $VERSION = '0.70';
 
-use warnings;
-use strict;
-
 #use Data::Dumper;
 use English qw( -no_match_vars );
 use File::Copy;
@@ -549,90 +550,6 @@ sub reinstall {
     return $self->create();
 }
 
-sub transition {
-    my $self = shift;
-
-# TODO: this method is almost identical to disable. Remove after 10/1/2010
-    my $ctid = $vos->{name};
-    $log->audit("transitioning $ctid");
-
-    return $log->error( "$ctid does not exist",
-        fatal   => $vos->{fatal},
-        debug   => $vos->{debug},
-    ) if !$self->is_present( debug => 0 );
-
-    my $config = $self->get_ve_config_path();
-    if ( !-e $config && -e "$config.transition" ) {
-        $log->audit( "VE is already transitioned." );
-        return 1;
-    };
-
-    if ( !-e $config ) {
-        return $log->error( "configuration file ($config) for $ctid does not exist",
-            fatal => $vos->{fatal},
-            debug => $vos->{debug},
-        );
-    }
-
-    if ( $self->is_running() ) {
-        $self->stop() or return; 
-    };
-
-    move( $config, "$config.transition" )
-        or return $log->error( "\tunable to move file '$config': $!",
-        fatal   => $vos->{fatal},
-        debug   => $vos->{debug},
-        );
-
-    $log->audit("\ttransitioned $ctid.");
-    return 1;
-}
-
-sub untransition {
-    my $self = shift;
-
-# TODO: this method is almost identical to enable. Remove after 10/1/2010
-    my $ctid = $vos->{name};
-    $log->audit("restoring $ctid");
-
-    return $log->error( "$ctid does not exist",
-        fatal   => $vos->{fatal},
-        debug   => $vos->{debug},
-    ) if !$self->is_present( debug => 0 );
-
-    if ( $self->is_enabled() ) {
-        $log->audit("\t$ctid is already restored");
-        return $self->start();
-    };
-
-    my $config = $self->get_ve_config_path();
-    if ( !-e "$config.transition" ) {
-        return $log->error( "configuration file ($config.transition) for $ctid does not exist",
-            fatal => $vos->{fatal},
-            debug => $vos->{debug},
-        );
-    }
-
-    move( "$config.transition", $config )
-        or return $log->error( "\tunable to move file '$config': $!",
-        fatal   => $vos->{fatal},
-        debug   => $vos->{debug},
-        );
-
-    return $self->start();
-
-    my $arpsend = $util->find_bin( 'arpsend', fatal => 0 );
-    if ( -x $arpsend ) {
-        my @ips = grep { /vif$ctid/ } `netstat -rn`;
-        foreach my $ip ( @ips ) {
-            $prov->audit( "$arpsend -U -c2 -i $_ eth0" );
-            system "$arpsend -U -c2 -i $_ eth0";
-        };
-
-        return 1;
-    }
-}
-
 sub console {
     my $self = shift;
     my $ve_name = $self->get_ve_name();
@@ -943,10 +860,10 @@ sub gen_config {
     my $kernel_dir = $self->get_kernel_dir();
     my $kernel_version = $self->get_kernel_version();
 
-    my ($kernel) = <$kernel_dir/vmlinuz*$kernel_version*>;
-    my ($ramdisk) = <$kernel_dir/initrd*$kernel_version*>;
-    ($kernel) ||= </boot/vmlinuz-*xen>;
-    ($ramdisk) ||= </boot/initrd-*xen.img>;
+    my ($kernel) = glob("$kernel_dir/vmlinuz*$kernel_version*");
+    my ($ramdisk) = glob("$kernel_dir/initrd*$kernel_version*");
+    ($kernel) ||= glob("/boot/vmlinuz-*xen");
+    ($ramdisk) ||= glob("/boot/initrd-*xen.img");
     my $cpu = $vos->{cpu} || 1;
     my $time_dt = $prov->get_datetime_from_epoch();
 
@@ -1046,7 +963,7 @@ sub get_kernel_version {
     my $self = shift;
     return $vos->{kernel_version} if $vos->{kernel_version};
     my $kernel_dir = $self->get_kernel_dir();
-    my @kernels = <$kernel_dir/vmlinuz-*xen>;
+    my @kernels = glob("$kernel_dir/vmlinuz-*xen");
     my $kernel = $kernels[0];
     my ($version) = $kernel =~ /-([0-9\.\-]+)\./;
     return $log->error("unable to detect a xen kernel (vmlinuz-*xen) in standard locations (/boot, /boot/domU)", fatal => 0) if ! $version;
@@ -1103,7 +1020,6 @@ sub get_status {
     my $config_file = $self->get_ve_config_path();
     if ( ! -e $config_file ) {
         return { state => 'disabled' } if -e "$config_file.suspend";
-        return { state => 'transitioned' } if -e "$config_file.transition";
 
         $log->audit( "\tmissing config file $config_file" );
         return { state => 'broken' };
@@ -1167,20 +1083,20 @@ sub get_status {
         };
         return $self->{status}{$ctid};
     }
-
-    sub _run_state {
-        my $abbr = shift;
-        return
-              $abbr =~ /r/ ? 'running'
-            : $abbr =~ /b/ ? 'running' # blocked is a 'wait' state, poorly named
-            : $abbr =~ /p/ ? 'paused'
-            : $abbr =~ /s/ ? 'shutdown'
-            : $abbr =~ /c/ ? 'crashed'
-            : $abbr =~ /d/ ? 'dying'
-            :                undef;
-    }
 }
 
+sub _run_state {
+    my $abbr = shift;
+    return
+          $abbr =~ /r/ ? 'running'
+        : $abbr =~ /b/ ? 'running' # blocked is a 'wait' state, poorly named
+        : $abbr =~ /p/ ? 'paused'
+        : $abbr =~ /s/ ? 'shutdown'
+        : $abbr =~ /c/ ? 'crashed'
+        : $abbr =~ /d/ ? 'dying'
+        :                undef;
+};
+
 sub get_swap_image {
     my $self = shift;
     my $path = shift;
@@ -1276,8 +1192,10 @@ sub get_xen_config {
     my $config_file = $self->get_ve_config_path();   # no config file, don't bother
     return if ! -f $config_file;
 
+    ## no critic
     eval "require Provision::Unix::VirtualOS::Xen::Config";  # won't load
     return if $@;
+    ## use critic
 
     my $xen_conf = Provision::Unix::VirtualOS::Xen::Config->new();
 
@@ -1548,9 +1466,9 @@ sub resize_disk_image {
         $cmd .= " --size=${target_size}M $image_path";
         $log->audit($cmd);
         #system $cmd and $log->error( "Error:  Unable to reduce filesystem on $image_name" );
-        open(FH, "| $cmd" ) or return $log->error("failed to shrink logical volume");
-        print FH "y\n";  # deals with the non-suppressible "Are you sure..." 
-        close FH;        # waits for the open process to exit
+        open(my $FH, '|', $cmd ) or return $log->error("failed to shrink logical volume");
+        print $FH "y\n";  # deals with the non-suppressible "Are you sure..." 
+        close $FH;        # waits for the open process to exit
         $log->audit("completed shrinking logical volume size");
         $self->do_fsck();
         return 1;
@@ -1861,7 +1779,7 @@ sub cleanup_inactive_snapshots {
     my $ps = $util->find_bin('ps',debug=>0);
     my $grep = $util->find_bin('grep',debug=>0);
 
-    foreach my $snap ( </dev/vol00/*_snap> ) {
+    foreach my $snap ( glob('/dev/vol00/*_snap') ) {
         my ($veid) = $snap =~ /\/([0-9]+)_rootimg_snap/;
         next if ! $veid;
         my @rsync_procs = `$ps ax | $grep rsync | $grep -v grep | $grep $veid`;
@@ -1877,11 +1795,17 @@ sub cleanup_inactive_snapshots {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Provision::Unix::VirtualOS::Linux::Xen - Provision Xen VEs
+Provision::Unix::VirtualOS::Linux::Xen - provision a linux VPS using Xen
+
+=head1 VERSION
+
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -1892,27 +1816,19 @@ Provision::Unix::VirtualOS::Linux::Xen - Provision Xen VEs
   my $vos  = Provision::Unix::VirtualOS->new( prov => $prov );
  
   $vos->create()
-  
+
 General 
 
-=head1 AUTHOR
-
-Matt Simerson, C<< <matt at tnpi.net> >>
-
-
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-unix-provision-virtualos at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Provision-Unix>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Provision::Unix::VirtualOS::Linux::Xen
 
-
 You can also look for information at:
 
 =over 4
@@ -1935,17 +1851,22 @@ L<http://search.cpan.org/dist/Provision-Unix>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
+=head1 AUTHOR
 
-=head1 COPYRIGHT & LICENSE
+Matt Simerson <msimerson@cpan.org>
 
-Copyright (c) 2009 Matt Simerson
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2011 by The Network People, Inc..
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
